@@ -1,5 +1,5 @@
 package File::Dir::Dumper::App;
-$File::Dir::Dumper::App::VERSION = '0.6.4';
+$File::Dir::Dumper::App::VERSION = '0.6.5';
 use warnings;
 use strict;
 
@@ -8,10 +8,10 @@ use 5.012;
 use parent 'File::Dir::Dumper::Base';
 
 use Getopt::Long qw(GetOptionsFromArray);
-use Pod::Usage qw( pod2usage );
+use Pod::Usage   qw( pod2usage );
 
-use File::Dir::Dumper::Scanner              ();
-use File::Dir::Dumper::Stream::JSON::Writer ();
+use File::Dir::Dumper::Scanner   ();
+use Format::JSON::Stream::Writer ();
 
 use Class::XSAccessor accessors => {
     _digest_cache        => '_digest_cache',
@@ -92,7 +92,7 @@ sub run
             digest_cache_params => $self->_digest_cache_params,
         }
     );
-    my $writer = File::Dir::Dumper::Stream::JSON::Writer->new(
+    my $writer = Format::JSON::Stream::Writer->new(
         {
             output => $out,
         }
@@ -124,7 +124,7 @@ dumping.
 
 =head1 VERSION
 
-version 0.6.4
+version 0.6.5
 
 =head1 SYNOPSIS
 
