@@ -1,83 +1,11 @@
 package File::Dir::Dumper::Stream::JSON::Reader;
-$File::Dir::Dumper::Stream::JSON::Reader::VERSION = '0.6.4';
-use warnings;
+$File::Dir::Dumper::Stream::JSON::Reader::VERSION = '0.6.5';
+use 5.014;
 use strict;
+use warnings;
 
-use 5.012;
+use parent 'Format::JSON::Stream::Reader';
 
-use parent 'File::Dir::Dumper::Base';
-
-use Carp ();
-
-use JSON::MaybeXS qw(decode_json);
-use Class::XSAccessor accessors => { _in => 'in' };
-
-
-sub _init
-{
-    my $self = shift;
-    my $args = shift;
-
-    $self->_in( $args->{input} );
-
-    $self->_init_stream();
-
-    return;
-}
-
-sub _readline
-{
-    my $self = shift;
-
-    return readline( $self->_in() );
-}
-
-sub _eof
-{
-    my $self = shift;
-
-    return eof( $self->_in() );
-}
-
-sub _init_stream
-{
-    my $self = shift;
-
-    if ( $self->_readline() ne "# JSON Stream by Shlomif - Version 0.2.0\n" )
-    {
-        Carp::confess "No header for JSON stream";
-    }
-
-    return;
-}
-
-sub fetch
-{
-    my $self = shift;
-
-    my $buffer = "";
-    my $line;
-
-    if ( $self->_eof() )
-    {
-        return;
-    }
-
-LINES:
-    while ( !$self->_eof() )
-    {
-        $line = $self->_readline();
-        if ( $line eq "--/f\n" )
-        {
-            return decode_json($buffer);
-        }
-        else
-        {
-            $buffer .= $line;
-        }
-    }
-    Carp::confess "Error! Reached end of file without record terminator.";
-}
 
 
 1;    # End of File::Dir::Dumper
@@ -94,11 +22,11 @@ File::Dir::Dumper::Stream::JSON::Reader - reader for stream of JSON objects.
 
 =head1 VERSION
 
-version 0.6.4
+version 0.6.5
 
 =head1 SYNOPSIS
 
-    use File::Dir::Dumper::Stream::JSON::Reader;
+    use File::Dir::Dumper::Stream::JSON::Reader ();
 
     my $reader = File::Dir::Dumper::Stream::JSON::Reader->new(
         {
