@@ -1,64 +1,11 @@
 package File::Dir::Dumper::Stream::JSON::Writer;
-$File::Dir::Dumper::Stream::JSON::Writer::VERSION = '0.6.4';
-use warnings;
+$File::Dir::Dumper::Stream::JSON::Writer::VERSION = '0.6.5';
+use 5.014;
 use strict;
+use warnings;
 
-use 5.012;
+use parent 'Format::JSON::Stream::Writer';
 
-use parent 'File::Dir::Dumper::Base';
-
-use Carp ();
-
-use JSON::MaybeXS ();
-use Class::XSAccessor accessors => { _out => '_out' };
-
-
-sub _init
-{
-    my $self = shift;
-    my $args = shift;
-
-    $self->_out( $args->{output} );
-
-    $self->_init_stream();
-
-    return;
-}
-
-sub _print
-{
-    my $self = shift;
-    my $line = shift;
-
-    print { $self->_out() } $line, "\n";
-}
-
-sub _init_stream
-{
-    my $self = shift;
-
-    $self->_print("# JSON Stream by Shlomif - Version 0.2.0");
-
-    return;
-}
-
-sub put
-{
-    my $self  = shift;
-    my $token = shift;
-
-    $self->_print( JSON::MaybeXS->new( canonical => 1 )->encode($token) );
-    $self->_print("--/f");
-
-    return;
-}
-
-sub close
-{
-    my $self = shift;
-
-    return close( $self->_out() );
-}
 
 
 1;    # End of File::Dir::Dumper
@@ -75,11 +22,11 @@ File::Dir::Dumper::Stream::JSON::Writer - writer for a stream of JSON data.
 
 =head1 VERSION
 
-version 0.6.4
+version 0.6.5
 
 =head1 SYNOPSIS
 
-    use File::Dir::Dumper::Stream::JSON::Writer;
+    use File::Dir::Dumper::Stream::JSON::Writer ();
 
     my $writer = File::Dir::Dumper::Stream::JSON::Writer->new(
         {
